function SimpleDisplay (config, target_currency, exchange_rates, value, numeric_type) {
	// if no exchange rates, create defaults
	if (exchange_rates.length > 0) {
		var my_rate = exchange_rates[target_currency][0];
		var my_decimals = exchange_rates[target_currency][1];
	} else {
		var my_rate = 1;
		var my_decimals = config.Currency_Decimals;
	}
	// do currency conversion
	if ((numeric_type == 'NT_FLOAT') && (config.Currency != target_currency)) {
		value = value * my_rate;
	}
	if (numeric_type == 'NT_PERC') {
		return format_perc(value, 2);
	} else {
		return format_float(value, my_decimals);
	}
}

function FormatDisplay (config, target_currency, exchange_rates, values, display_value, numeric_type) {
	// if no exchange rates, create defaults
	if (exchange_rates.length > 0) {
		var my_rate = exchange_rates[target_currency][0];
		var my_decimals = exchange_rates[target_currency][1];
	} else {
		var my_rate = 1;
		var my_decimals = config.Currency_Decimals;
	}
	// do currency conversion
	if ((numeric_type == 'NT_FLOAT') && (config.Currency != target_currency)) {
		values[0] = values[0] * my_rate;
		values[1] = values[1] * my_rate;
	}
	if (values[0] > values[1]) {
		if (numeric_type == 'NT_PERC') {
			return format_perc(values[display_value], 2);
		} else {
			return format_float(values[display_value], my_decimals);
		}
	} else {
		if (numeric_type == 'NT_PERC') {
			return '<font color="red">' + format_perc(values[display_value], 2) + '</font>';
		} else {
			return '<font color="red">' + format_float(values[display_value], my_decimals) + '</font>';
		}
	}
}

function PresentValue (i_rate, periods, payment, future_value) {
	pv = 0;
	fv = parseFloat(future_value);
	np = parseFloat(periods);
	pmt = parseFloat(payment);
	ir = (parseFloat(i_rate) / 12) / 100;

	if(ir == 0) {
		pv = -(fv + (pmt * np));
	} else {
		q1 = Math.pow(1 + ir,-np);
		q2 = Math.pow(1 + ir,np);
		pv = -(q1 * (fv * ir - pmt + q2 * pmt))/ir;
	}
	return pv;
}

function Payment (i_rate, periods, present_value, future_value) {
	pv = parseFloat(present_value);
	fv = parseFloat(future_value);
	np = parseFloat(periods);
	pmt = 0;
	ir = (parseFloat(i_rate) / 12) / 100;

	if(ir == 0.0) {
		if(np != 0) {
			pmt = - (fv + pv)/np;
		} else {
			alert("Divide by zero error.");
		}
	} else {
		q = Math.pow(1 + ir,np);
		pmt = -((ir * (fv + q * pv))/(-1 + q));
	}
	return pmt;
}

function IdealMaxOffer (periods, payment, rv_ratio) {
	return ((PresentValue (8, periods, -payment, 0) * 0.75) / rv_ratio) / 100;
}

function CalcBondValue (current_balance, payment, i_rate, periods) {
	var counter		= 0;
	var pmt			= 0;
	var principal	= 0;

	for (counter = 1; counter <= periods; counter++) {
		pmt = current_balance * (i_rate / 12);
		principal = payment - pmt;
		current_balance = current_balance - principal;
	}
	return current_balance;
}

function calcValuator ( prop_config, my_form ) {
	var rentpm			= parseFloat (unformat_number (my_form.elements['rent_pm'].value, prop_config.Currency_Decimals));
	var rv_ratio		= parseFloat (unformat_number (my_form.elements['rv_ratio'].value, prop_config.Currency_Decimals));
	var bond_term		= my_form.elements['bond_term'].value;

	if (rv_ratio != 0.00) {
		var own_value		= (rentpm / rv_ratio) * 100;
		if (rv_ratio > 0) {
			max_offer		= IdealMaxOffer ((bond_term * 12), rentpm, (rv_ratio / 100));
		} else {
			max_offer		= 0;
		}
		var purchase_price	= max_offer;
		var bond_amt		= (rentpm / rv_ratio) * 100;
	} else {
		var own_value		= 0;
		var purchase_price	= 0;
		var bond_amt		= 0;
	}

//	document.getElementById ('own_value').innerHTML			= FormatDisplay (prop_config, prop_config.Currency, Array(), new Array(own_value, 0), 0, 'NT_FLOAT');
//	document.getElementById ('purchase_price').innerHTML	= FormatDisplay (prop_config, prop_config.Currency, Array(), new Array(purchase_price, 0), 0, 'NT_FLOAT');
//	document.getElementById ('bond_amt').innerHTML			= FormatDisplay (prop_config, prop_config.Currency, Array(), new Array(bond_amt, 0), 0, 'NT_FLOAT');

	my_form.elements['own_value'].value			= SimpleDisplay (prop_config, prop_config.Currency, Array(), own_value, 'NT_FLOAT');
	my_form.elements['purchase_price'].value	= SimpleDisplay (prop_config, prop_config.Currency, Array(), purchase_price, 'NT_FLOAT');
	my_form.elements['bond_amt'].value			= SimpleDisplay (prop_config, prop_config.Currency, Array(), bond_amt, 'NT_FLOAT');
}

function calcQuickAnswers (prop_config, exchange_rates, target_currency, my_form, type) {
	// input values
	var bond_term			= parseFloat(unformat_number (my_form.elements['bond_term'].value, prop_config.Currency_Decimals));
	var own_value			= parseFloat(unformat_number (my_form.elements['own_value'].value, prop_config.Currency_Decimals));
	var purchase_price		= parseFloat(unformat_number (my_form.elements['purchase_price'].value, prop_config.Currency_Decimals));
	var avail_bond_amt		= 0.00;
	if (type == 'property') {
		avail_bond_amt		= parseFloat(unformat_number (my_form.elements['avail_bond_amt'].value, prop_config.Currency_Decimals));
	}
	var bond_amt			= parseFloat(unformat_number (my_form.elements['bond_amt'].value, prop_config.Currency_Decimals));
	var deposit				= parseFloat(unformat_number (my_form.elements['deposit'].value, prop_config.Currency_Decimals));
	var costs				= parseFloat(unformat_number (my_form.elements['costs'].value, prop_config.Currency_Decimals));
	var levies				= parseFloat(unformat_number (my_form.elements['levies'].value, prop_config.Currency_Decimals));
	var rentpm				= parseFloat(unformat_number (my_form.elements['rent_pm'].value, prop_config.Currency_Decimals));

	// output values
	var total_capex		= 0.00;
	var bond_pmt_pm		= 0.00;
	var ss_pm			= 0.00;
	var bond_balance	= 0.00;
	var equity			= 0.00;
	var nroi			= 0.00;
	var ror				= 0.00;
	var transfer_cost	= 0.00;
	var cashflow		= 0.00;
	var rv_ratio		= 0.00;
	var max_offer		= 0.00;
	// working values
	var rentpa			= 0.00;
	var net_income		= 0.00;

	total_capex			= deposit + costs;
	if (prop_config.Bond_Type == 0) {
		// interest only loan
		bond_pmt_pm		= (bond_amt * (prop_config.Int_Rate / 100)) / 12;
	} else {
		// normal loan
		bond_pmt_pm		= Payment (prop_config.Int_Rate, (bond_term * 12), -bond_amt, 0);
	}
	rentpa				= rentpm * 12;
	net_income			= rentpa - (rentpa * (prop_config.Vacancy_Rate / 100)) - (rentpa * (prop_config.Maint_Rate / 100)) - (rentpa * (prop_config.Comm_Rate / 100)) - (levies * 12);
	ss_pm				= (net_income - (bond_pmt_pm * 12)) / 12;
	transfer_cost		= purchase_price * (prop_config.Transfer_Cost / 100);
	cashflow				= (bond_amt - purchase_price - transfer_cost - costs) + (ss_pm * 12);
	if (own_value > 0) {
		rv_ratio		= (rentpm / own_value) * 100;
	} else {
		rv_rate			= 0;
	}
	if (rv_ratio > 0) {
		max_offer		= IdealMaxOffer ((bond_term * 12), rentpm, (rv_ratio / 100));
	} else {
		max_offer		= 0;
	}
	if (purchase_price > max_offer) {
//		my_form.elements['purchase_price'].className		= 'input_alert';
//		.input { font-family: verdana; font-size: 11px; border: 1px solid #999999; }

		my_form.elements['purchase_price'].style.border	= '1px solid #666666';
		//my_form.elements['purchase_price'].style.background	= '#ff0000';
		//my_form.elements['purchase_price'].style.color		= "#ffffff";
	} else {
//		my_form.elements['purchase_price'].className		= 'input';
		my_form.elements['purchase_price'].style.border	= '1px solid #999999';
		//my_form.elements['purchase_price'].style.background	= '#ffffff';
		//my_form.elements['purchase_price'].style.color		= "#000000";
	}
	if (prop_config.Bond_Type == 0) {
		//Changed - Coert [2011-04-17]
		//equity 		= ((own_value * (prop_config.Growth_Rate / 100)) + own_value) - bond_amt;
		equity 			= own_value - bond_amt;
	} else {
		//Changed - Coert [2011-04-17]
		//equity 		= ((own_value * (prop_config.Growth_Rate / 100)) + own_value) - CalcBondValue (bond_amt, bond_pmt_pm, (prop_config.Int_Rate / 100), 12);
		equity 			= own_value - bond_amt;
	}
	nroi				= equity - total_capex + (ss_pm * 12);
	if (equity > 0) {
		ror				= (nroi / Math.abs (cashflow)) * 100;
	} else {
		ror				= 0;
	}
	bond_balance		= avail_bond_amt - bond_amt;
	
	document.getElementById ('total_capex').innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(total_capex, 0), 0, 'NT_FLOAT');
	document.getElementById ('bond_pmt_pm').innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(bond_pmt_pm, 0), 0, 'NT_FLOAT');
	document.getElementById ('ss_pm').innerHTML				= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(ss_pm, 0), 0, 'NT_FLOAT');
	document.getElementById ('rv_ratio').innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(rv_ratio, 0), 0, 'NT_PERC');
	document.getElementById ('equity').innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(equity, 0), 0, 'NT_FLOAT');
	document.getElementById ('nroi').innerHTML				= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(nroi, 0), 0, 'NT_FLOAT');
	if (type != 'property') {
		document.getElementById ('max_offer').innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(max_offer, 0), 0, 'NT_FLOAT');
		document.getElementById ('cashflow').innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(cashflow, 0), 0, 'NT_FLOAT');
		document.getElementById ('transfer_cost').innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(transfer_cost, 0), 0, 'NT_FLOAT');
		document.getElementById ('ror').innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(ror, 0), 0, 'NT_PERC');
	} else {
		document.getElementById ('bond_balance').innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(bond_balance, 0), 0, 'NT_FLOAT');
	}
}

function calcPropertyDetails (prop_config, exchange_rates, target_currency, my_form) {
	// input values
	var own_value		= parseFloat (unformat_number (my_form.elements['own_value'].value, prop_config.Currency_Decimals));
	var purchase_price	= parseFloat (unformat_number (my_form.elements['purchase_price'].value, prop_config.Currency_Decimals));
	var avail_bond_amt	= parseFloat (unformat_number (my_form.elements['avail_bond_amt'].value, prop_config.Currency_Decimals));
	var bond_amt		= parseFloat (unformat_number (my_form.elements['bond_amt'].value, prop_config.Currency_Decimals));
	var deposit			= parseFloat (unformat_number (my_form.elements['deposit'].value, prop_config.Currency_Decimals));
	var costs			= parseFloat (unformat_number (my_form.elements['costs'].value, prop_config.Currency_Decimals));
	var rentpm			= parseFloat (unformat_number (my_form.elements['rent_pm'].value, prop_config.Currency_Decimals));
	var levies			= parseFloat (unformat_number (my_form.elements['levies'].value, prop_config.Currency_Decimals));
	// output values
	var bond_pmt_pm		= 0.00;
	var bond_balance	= 0.00;
	var equity			= 0.00;
	var total_capex		= 0.00;
	var ss_pm			= 0.00;
	var nroi			= 0.00;
	var comm			= 0.00;
	var vacancy			= 0.00;
	var maint			= 0.00;
	var rv_ratio		= 0.00;

	total_capex			= deposit + costs;
	if (prop_config.Bond_Type == 0) {
		// interest only loan
		bond_pmt_pm		= (bond_amt * (prop_config.Int_Rate / 100)) / 12;
		//Changed - Coert [2011-04-17]
		//equity 			= ((own_value * (prop_config.Growth_Rate / 100)) + own_value) - bond_amt;
		equity 			= own_value - bond_amt;
	} else {
		// normal loan
		bond_pmt_pm		= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -bond_amt, 0);
		//Changed - Coert [2011-04-17]
		//equity 			= ((own_value * (prop_config.Growth_Rate / 100)) + own_value) - CalcBondValue (bond_amt, bond_pmt_pm, (prop_config.Int_Rate / 100), 12);
		equity 			= own_value - bond_amt;
	}
	rentpa				= rentpm * 12;
	net_income			= rentpa - (rentpa * (prop_config.Vacancy_Rate / 100)) - (rentpa * (prop_config.Maint_Rate / 100)) - (rentpa * (prop_config.Comm_Rate / 100)) - (levies * 12);
	ss_pm				= (net_income - (bond_pmt_pm * 12)) / 12;
	nroi				= equity - total_capex + (ss_pm * 12);
	comm				= rentpm * (prop_config.Comm_Rate / 100);
	vacancy				= rentpm * (prop_config.Vacancy_Rate / 100);
	maint				= rentpm * (prop_config.Maint_Rate / 100);
	bond_balance		= avail_bond_amt - bond_amt;
	if (own_value > 0) {
		rv_ratio		= (rentpm / own_value) * 100;
	} else {
		rv_rate			= 0;
	}

	document.getElementById ('bond_pmt_pm').innerHTML	= FormatDisplay (prop_config, prop_config.Currency, Array(), new Array(bond_pmt_pm, 0), 0, 'NT_FLOAT');
	document.getElementById ('bond_balance').innerHTML	= FormatDisplay (prop_config, prop_config.Currency, Array(), new Array(bond_balance, 0), 0, 'NT_FLOAT');
	document.getElementById ('equity').innerHTML		= FormatDisplay (prop_config, prop_config.Currency, Array(), new Array(equity, 0), 0, 'NT_FLOAT');
	document.getElementById ('total_capex').innerHTML	= FormatDisplay (prop_config, prop_config.Currency, Array(), new Array(total_capex, 0), 0, 'NT_FLOAT');
	document.getElementById ('nroi').innerHTML			= FormatDisplay (prop_config, prop_config.Currency, Array(), new Array(nroi, 0), 0, 'NT_FLOAT');
	document.getElementById ('ss_pm').innerHTML			= FormatDisplay (prop_config, prop_config.Currency, Array(), new Array(ss_pm, 0), 0, 'NT_FLOAT');
	document.getElementById ('comm').innerHTML			= FormatDisplay (prop_config, prop_config.Currency, Array(), new Array(comm, 0), 0, 'NT_FLOAT');
	document.getElementById ('vacancy').innerHTML		= FormatDisplay (prop_config, prop_config.Currency, Array(), new Array(vacancy, 0), 0, 'NT_FLOAT');
	document.getElementById ('maint').innerHTML			= FormatDisplay (prop_config, prop_config.Currency, Array(), new Array(maint, 0), 0, 'NT_FLOAT');
	document.getElementById ('rv_ratio').innerHTML		= FormatDisplay (prop_config, prop_config.Currency, Array(), new Array(rv_ratio, 0), 0, 'NT_PERC');
}

function calcDealProjection (deal, prop_config, exchange_rates, target_currency, my_form) {
	// general variables
	var counter			= 0;
	var eq_count		= 0;
	
	// input values
	var eq_withs		= new Array();
	for (counter = 1; counter <= 20; counter++) {
		eq_withs[counter]	= parseFloat (unformat_number (my_form.elements['eq_with_' + counter].value, prop_config.Currency_Decimals));
//		eq_withs[counter]	= unformat_number (my_form.elements['eq_with_' + counter].value, prop_config.Currency_Decimals);
	}

	// working variables
//	var bond_pmt_pm		= 0.00;
	var eq_with			= 0.00;
	var projection		= new Array();
	var eq_amt			= 0.00;
	var eq_pmt			= 0.00;
//	var cashflow		= 0.00;

	projection[1]		= new Object();
	projection[1].Own_Value			= (deal.Own_Valuation * (prop_config.Growth_Rate / 100)) + deal.Own_Valuation;
	if (prop_config.Bond_Type == 0) {
		// interest only loan
		projection[1].Bond_Amt			= deal.Bond_Amt;
//		bond_pmt_pm		= (bond_amt * (prop_config.Int_Rate / 100)) / 12;
		projection[1].Bond_Pmt			= (deal.Bond_Amt * (prop_config.Int_Rate / 100)) / 12;
	} else {
		// normal loan
		projection[1].Bond_Pmt			= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -deal.Bond_Amt, 0);
		projection[1].Bond_Amt			= CalcBondValue (deal.Bond_Amt, projection[1].Bond_Pmt, (prop_config.Int_Rate / 100), 12);
	}
	projection[1].Gearing_Ratio			= (projection[1].Bond_Amt / projection[1].Own_Value) * 100;
	projection[1].Bond_Pmt				*= 12;
	projection[1].Rental_Income			= deal.Rent_PM * 12;
	projection[1].Vacancy_Amt			= projection[1].Rental_Income * (prop_config.Vacancy_Rate / 100);
	projection[1].Maint_Amt				= projection[1].Rental_Income * (prop_config.Maint_Rate / 100);
	projection[1].Comm_Amt				= projection[1].Rental_Income * (prop_config.Comm_Rate / 100);
	projection[1].Levies				= deal.Levies * 12;
	projection[1].Net_Income			= projection[1].Rental_Income - projection[1].Vacancy_Amt - projection[1].Maint_Amt - projection[1].Comm_Amt - projection[1].Levies;
	projection[1].Surplus_Shortfall		= projection[1].Net_Income - projection[1].Bond_Pmt;
	projection[1].Accumulated			= projection[1].Surplus_Shortfall;
	projection[1].Equity				= projection[1].Own_Value - projection[1].Bond_Amt;
	projection[1].NROI					= projection[1].Equity - deal.Deposit - deal.Costs + projection[1].Surplus_Shortfall;
	projection[1].Cashflow				= (deal.Bond_Amt - deal.Purchase_Price - (deal.Purchase_Price * (prop_config.Transfer_Cost / 100)) - deal.Costs) + (projection[1].Surplus_Shortfall);
//	cashflow							= (deal.Bond_Amt - deal.Purchase_Price - (deal.Purchase_Price * (prop_config.Transfer_Cost / 100)) - deal.Costs) + (projection[1].Surplus_Shortfall);
	if (projection[1].Cashflow < 0) {
		projection[1].Acc_ROR			= (projection[1].NROI / Math.abs (projection[1].Cashflow)) * 100;
	} else {
		projection[1].Acc_ROR			= 0.00;
	}

	for (counter = 2; counter <= 20; counter++) {
		projection[counter]					= new Object();
 		projection[counter].Own_Value		= (projection[counter - 1].Own_Value * (prop_config.Growth_Rate / 100)) + projection[counter - 1].Own_Value;
		if (prop_config.Bond_Type == 0) {
			eq_with = 0.00;
			for (eq_count = 1; eq_count < counter; eq_count++) {
				if (eq_count >= (counter - prop_config.Bond_Term)) {
					eq_with += eq_withs[eq_count];
				}
			}
			if (counter >= prop_config.Bond_Term) {
				projection[counter].Bond_Amt = eq_with;
			} else {
				projection[counter].Bond_Amt = deal.Bond_Amt + eq_with;
			}
			projection[counter].Bond_Pmt = (projection[counter].Bond_Amt * (prop_config.Int_Rate / 100)) / 12;
		} else {
			projection[counter].Bond_Pmt	= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -deal.Bond_Amt, 0);
			projection[counter].Bond_Amt	= CalcBondValue (deal.Bond_Amt, projection[counter].Bond_Pmt, (prop_config.Int_Rate / 100), (counter * 12));

			for (eq_count = 1; eq_count < counter; eq_count++) {
				if (eq_withs[eq_count] > 0) {
                    eq_pmt					= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -eq_withs[eq_count], 0);
                    eq_amt					= CalcBondValue (eq_withs[eq_count], eq_pmt, (prop_config.Int_Rate / 100), ((counter - eq_count) * 12));
//                    eq_withs[eq_count - 1]	= CalcBondValue (eq_withs[eq_count], eq_pmt, (prop_config.Int_Rate / 100), ((counter - eq_count) * 12));

					projection[counter].Bond_Amt		+= eq_amt;
					projection[counter].Bond_Pmt		+= eq_pmt;
				}
				if (projection[counter].Bond_Amt <= 0) {
					projection[counter].Bond_Amt		= 0.00;
					projection[counter].Bond_Pmt		= 0.00;
				}
			}
		}
		projection[counter].Gearing_Ratio				= (projection[counter].Bond_Amt / projection[counter].Own_Value) * 100;
		projection[counter].Bond_Pmt					*= 12;
		projection[counter].Rental_Income				= projection[counter - 1].Rental_Income + (projection[counter - 1].Rental_Income * (prop_config.Inf_Rate / 100));
		projection[counter].Vacancy_Amt					= projection[counter].Rental_Income * (prop_config.Vacancy_Rate / 100);
		projection[counter].Maint_Amt					= projection[counter].Rental_Income * (prop_config.Maint_Rate / 100);
		projection[counter].Comm_Amt					= projection[counter].Rental_Income * (prop_config.Comm_Rate / 100);
		projection[counter].Levies						= projection[counter - 1].Levies + (projection[counter - 1].Levies * (prop_config.Inf_Rate / 100));
		projection[counter].Net_Income					= projection[counter].Rental_Income - projection[counter].Vacancy_Amt - projection[counter].Maint_Amt - projection[counter].Comm_Amt - projection[counter].Levies;
		projection[counter].Surplus_Shortfall			= projection[counter].Net_Income - projection[counter].Bond_Pmt;
		projection[counter].Accumulated					= projection[counter - 1].Accumulated + projection[counter].Surplus_Shortfall;
		projection[counter].Equity						= projection[counter].Own_Value - projection[counter].Bond_Amt;
		projection[counter].NROI						= projection[counter].Equity - deal.Deposit - deal.Costs + projection[counter].Surplus_Shortfall;
		projection[counter].Cashflow          			= projection[counter - 1].Cashflow + (projection[counter].Surplus_Shortfall);
		if (projection[counter].Cashflow < 0) {
			projection[counter].Acc_ROR					= (projection[counter].NROI / Math.abs (projection[counter].Cashflow)) * 100;
		} else {
			projection[counter].Acc_ROR					= 0.00;
		}
	}
	for (counter = 1; counter < 20; counter++) {
		projection[counter].Provision		= projection[counter + 1].Surplus_Shortfall - prop_config.Refinance_Cost;
		projection[counter].Cash_In_Hand		= eq_withs[counter] + projection[counter].Provision;
	}

	document.getElementById ('own_value_1').innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[1].Own_Value, 0), 0, 'NT_FLOAT');
	document.getElementById ('bond_amt_1').innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[1].Bond_Amt, 0), 0, 'NT_FLOAT');
	document.getElementById ('bond_pmt_1').innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[1].Bond_Pmt, 0), 0, 'NT_FLOAT');
	document.getElementById ('gearing_ratio_1').innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(prop_config.Gearing, projection[1].Gearing_Ratio), 1, 'NT_PERC');
	document.getElementById ('rental_income_1').innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[1].Rental_Income, 0), 0, 'NT_FLOAT');
	document.getElementById ('vacancy_amt_1').innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[1].Vacancy_Amt, 0), 0, 'NT_FLOAT');
	document.getElementById ('maint_amt_1').innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[1].Maint_Amt, 0), 0, 'NT_FLOAT');
	document.getElementById ('comm_amt_1').innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[1].Comm_Amt, 0), 0, 'NT_FLOAT');
	document.getElementById ('levies_1').innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[1].Levies, 0), 0, 'NT_FLOAT');
	document.getElementById ('net_income_1').innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[1].Net_Income, 0), 0, 'NT_FLOAT');
	document.getElementById ('ss_1').innerHTML				= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[1].Surplus_Shortfall, 0), 0, 'NT_FLOAT');
	document.getElementById ('accumulated_1').innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[1].Accumulated, 0), 0, 'NT_FLOAT');
	document.getElementById ('equity_1').innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[1].Equity, 0), 0, 'NT_FLOAT');
	document.getElementById ('nroi_1').innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[1].NROI, 0), 0, 'NT_FLOAT');
	document.getElementById ('cashflow_1').innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[1].Cashflow, 0), 0, 'NT_FLOAT');
	document.getElementById ('acc_ror_1').innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[1].Acc_ROR, 0), 0, 'NT_PERC');
	document.getElementById ('provision_1').innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[1].Provision, 0), 0, 'NT_FLOAT');
	document.getElementById ('cash_1').innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[1].Cash_In_Hand, 0), 0, 'NT_FLOAT');
	for (counter = 2; counter <= 20; counter++) {
		document.getElementById ('own_value_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Own_Value, 0), 0, 'NT_FLOAT');
		document.getElementById ('bond_amt_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Bond_Amt, 0), 0, 'NT_FLOAT');
		document.getElementById ('bond_pmt_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Bond_Pmt, 0), 0, 'NT_FLOAT');
		document.getElementById ('gearing_ratio_' + counter).innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(prop_config.Gearing, projection[counter].Gearing_Ratio), 1, 'NT_PERC');
		document.getElementById ('rental_income_' + counter).innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Rental_Income, 0), 0, 'NT_FLOAT');
		document.getElementById ('vacancy_amt_' + counter).innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Vacancy_Amt, 0), 0, 'NT_FLOAT');
		document.getElementById ('maint_amt_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Maint_Amt, 0), 0, 'NT_FLOAT');
		document.getElementById ('comm_amt_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Comm_Amt, 0), 0, 'NT_FLOAT');
		document.getElementById ('levies_' + counter).innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Levies, 0), 0, 'NT_FLOAT');
		document.getElementById ('net_income_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Net_Income, 0), 0, 'NT_FLOAT');
		document.getElementById ('ss_' + counter).innerHTML				= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Surplus_Shortfall, 0), 0, 'NT_FLOAT');
		document.getElementById ('accumulated_' + counter).innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Accumulated, 0), 0, 'NT_FLOAT');
		document.getElementById ('equity_' + counter).innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Equity, 0), 0, 'NT_FLOAT');
		document.getElementById ('nroi_' + counter).innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].NROI, 0), 0, 'NT_FLOAT');
		document.getElementById ('cashflow_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Cashflow, 0), 0, 'NT_FLOAT');
		document.getElementById ('acc_ror_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Acc_ROR, 0), 0, 'NT_PERC');
		document.getElementById ('provision_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Provision, 0), 0, 'NT_FLOAT');
		document.getElementById ('cash_' + counter).innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Cash_In_Hand, 0), 0, 'NT_FLOAT');

		if ((projection[counter].Gearing_Ratio > prop_config.Gearing) && (eq_withs[counter-1] > 0)) {
			my_form.elements['eq_with_' + (counter - 1)].style.color='#ffffff';
			my_form.elements['eq_with_' + (counter - 1)].style.background='#ff0000';
		} else {
			my_form.elements['eq_with_' + (counter - 1)].style.color='#000000';
			my_form.elements['eq_with_' + (counter - 1)].style.background='#ffffff';
		}
	}
}

function calcPropProjection (deal, prop_config, exchange_rates, target_currency, my_form) {
	// general variables
	var counter			= 0;
	var eq_count		= 0;
	
	// input values
	var eq_withs		= new Array();
	for (counter =0; counter <= 20; counter++) {
		eq_withs[counter]	= parseFloat (unformat_number (my_form.elements['eq_with_' + counter].value, prop_config.Currency_Decimals));
//		eq_withs[counter]	= parseFloat (remove_formatting (my_form.elements['eq_with_' + counter].value));
	}

	// working variables
//	var bond_pmt_pm		= 0.00;
	var eq_with			= 0.00;
	var projection		= new Array();
	var eq_amt			= 0.00;
	var eq_pmt			= 0.00;
//	var cashflow		= 0.00;

	projection[0]					= new Object();
	projection[0].Own_Value			= deal.Own_Valuation;
	projection[0].Bond_Amt			= deal.Bond_Amt;
	if (prop_config.Bond_Type == 0) {
		// interest only loan
		projection[0].Bond_Pmt			= (deal.Bond_Amt * (prop_config.Int_Rate)) / 12;
	} else {
		projection[0].Bond_Pmt			= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -deal.Bond_Amt, 0);
	}
	projection[0].Gearing_Ratio			= (projection[0].Bond_Amt / projection[0].Own_Value) * 100;
	projection[0].Bond_Pmt				*= 12;
	projection[0].Rental_Income			= deal.Rent_PM * 12;

	projection[0].Vacancy_Amt			= projection[0].Rental_Income * (prop_config.Vacancy_Rate / 100);
	projection[0].Maint_Amt				= projection[0].Rental_Income * (prop_config.Maint_Rate / 100);
	projection[0].Comm_Amt				= projection[0].Rental_Income * (prop_config.Comm_Rate / 100);
	projection[0].Levies				= deal.Levies * 12;
	projection[0].Net_Income			= projection[0].Rental_Income - (projection[0].Vacancy_Amt + projection[0].Maint_Amt + projection[0].Comm_Amt + projection[0].Levies);
	projection[0].Surplus_Shortfall		= projection[0].Net_Income - projection[0].Bond_Pmt;
	projection[0].Accumulated			= projection[0].Surplus_Shortfall;
	projection[0].Equity				= projection[0].Own_Value - projection[0].Bond_Amt;
	projection[0].NROI					= projection[0].Equity - deal.Deposit - deal.Costs + projection[0].Surplus_Shortfall;
//	cashflow							= (deal.Bond_Amt - deal.Purchase_Price - deal.Costs) + (projection[0].Surplus_Shortfall);
	projection[0].Cashflow				= (deal.Bond_Amt - deal.Purchase_Price - deal.Costs) + projection[0].Surplus_Shortfall;
	if (projection[0].Cashflow < 0) {
		projection[0].Acc_ROR			= (projection[0].NROI / Math.abs (projection[0].Cashflow)) * 100;
	} else {
		projection[0].Acc_ROR			= 0.00;
	}

	projection[1]		= new Object();
	projection[1].Own_Value			= (deal.Own_Valuation * (prop_config.Growth_Rate / 100)) + deal.Own_Valuation;
	if (prop_config.Bond_Type == 0) {
		// interest only loan
//		projection[1].Bond_Amt			= deal.Bond_Amt;
//		bond_pmt_pm		= (bond_amt * (prop_config.Int_Rate / 100)) / 12;
//		projection[1].Bond_Pmt			= (deal.Bond_Amt * (prop_config.Int_Rate / 100)) / 12;

		eq_with = 0.00;
		for (eq_count = 0; eq_count < 1; eq_count++) {
			if (eq_count >= (1 - prop_config.Bond_Term)) {
				eq_with += eq_withs[eq_count];
			}
		}
		if (1 >= prop_config.Bond_Term) {
			projection[1].Bond_Amt = eq_with;
		} else {
			projection[1].Bond_Amt = deal.Bond_Amt + eq_with;
		}
		projection[1].Bond_Pmt = (projection[1].Bond_Amt * (prop_config.Int_Rate / 100)) / 12;
	} else {
		// normal loan
//		projection[1].Bond_Pmt			= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -deal.Bond_Amt, 0);
//		projection[1].Bond_Amt			= CalcBondValue (deal.Bond_Amt, projection[1].Bond_Pmt, (prop_config.Int_Rate / 100), 12);

		projection[1].Bond_Pmt			= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -deal.Bond_Amt, 0);
		projection[1].Bond_Amt			= CalcBondValue (deal.Bond_Amt, projection[1].Bond_Pmt, (prop_config.Int_Rate / 100), 12);

		for (eq_count = 0; eq_count < 1; eq_count++) {
			if (eq_withs[eq_count] > 0) {
                eq_pmt					= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -eq_withs[eq_count], 0);
                eq_amt					= CalcBondValue (eq_withs[eq_count], eq_pmt, (prop_config.Int_Rate / 100), ((1 - eq_count) * 12));
//                    eq_withs[eq_count - 1]	= CalcBondValue (eq_withs[eq_count], eq_pmt, (prop_config.Int_Rate / 100), ((1 - eq_count) * 12));

				projection[1].Bond_Amt		+= eq_amt;
				projection[1].Bond_Pmt		+= eq_pmt;
			}
			if (projection[1].Bond_Amt <= 0) {
				projection[1].Bond_Amt		= 0.00;
				projection[1].Bond_Pmt		= 0.00;
			}
		}
	}
	projection[1].Gearing_Ratio			= (projection[1].Bond_Amt / projection[1].Own_Value) * 100;
	projection[1].Bond_Pmt				*= 12;
	projection[1].Rental_Income			= projection[0].Rental_Income + (projection[0].Rental_Income * (prop_config.Inf_Rate / 100));
//	projection[1].Rental_Income			= deal.Rent_PM * 12;
	projection[1].Vacancy_Amt			= projection[1].Rental_Income * (prop_config.Vacancy_Rate / 100);
	projection[1].Maint_Amt				= projection[1].Rental_Income * (prop_config.Maint_Rate / 100);
	projection[1].Comm_Amt				= projection[1].Rental_Income * (prop_config.Comm_Rate / 100);
	projection[1].Levies				= projection[0].Levies + (projection[0].Levies * (prop_config.Inf_Rate / 100));
//	projection[1].Levies				= deal.Levies * 12;
	projection[1].Net_Income			= projection[1].Rental_Income - projection[1].Vacancy_Amt - projection[1].Maint_Amt - projection[1].Comm_Amt - projection[1].Levies;
	projection[1].Surplus_Shortfall		= projection[1].Net_Income - projection[1].Bond_Pmt;
	projection[1].Accumulated			= projection[0].Accumulated + projection[1].Surplus_Shortfall;
//	projection[1].Accumulated			= projection[1].Surplus_Shortfall;
	projection[1].Equity				= projection[1].Own_Value - projection[1].Bond_Amt;
	projection[1].NROI					= projection[1].Equity - deal.Deposit - deal.Costs + projection[1].Surplus_Shortfall;
	projection[1].Cashflow       		= projection[0].Cashflow + (projection[1].Surplus_Shortfall);
//	projection[1].Cashflow				= (deal.Bond_Amt - deal.Purchase_Price - (deal.Purchase_Price * (prop_config.Transfer_Cost / 100)) - deal.Costs) + (projection[1].Surplus_Shortfall);
//	cashflow							= (deal.Bond_Amt - deal.Purchase_Price - (deal.Purchase_Price * (prop_config.Transfer_Cost / 100)) - deal.Costs) + (projection[1].Surplus_Shortfall);
	if (projection[1].Cashflow < 0) {
		projection[1].Acc_ROR			= (projection[1].NROI / Math.abs (projection[1].Cashflow)) * 100;
	} else {
		projection[1].Acc_ROR			= 0.00;
	}

	for (counter = 2; counter <= 20; counter++) {
		projection[counter]					= new Object();
 		projection[counter].Own_Value		= (projection[counter - 1].Own_Value * (prop_config.Growth_Rate / 100)) + projection[counter - 1].Own_Value;
		if (prop_config.Bond_Type == 0) {
			eq_with = 0.00;
			for (eq_count = 0; eq_count < counter; eq_count++) {
				if (eq_count >= (counter - prop_config.Bond_Term)) {
					eq_with += eq_withs[eq_count];
				}
			}
			if (counter >= prop_config.Bond_Term) {
				projection[counter].Bond_Amt = eq_with;
			} else {
				projection[counter].Bond_Amt = deal.Bond_Amt + eq_with;
			}
			projection[counter].Bond_Pmt = (projection[counter].Bond_Amt * (prop_config.Int_Rate / 100)) / 12;
		} else {
			projection[counter].Bond_Pmt	= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -deal.Bond_Amt, 0);
			projection[counter].Bond_Amt	= CalcBondValue (deal.Bond_Amt, projection[counter].Bond_Pmt, (prop_config.Int_Rate / 100), (counter * 12));

			for (eq_count = 0; eq_count < counter; eq_count++) {
				if (eq_withs[eq_count] > 0) {
                    eq_pmt					= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -eq_withs[eq_count], 0);
                    eq_amt					= CalcBondValue (eq_withs[eq_count], eq_pmt, (prop_config.Int_Rate / 100), ((counter - eq_count) * 12));
//                    eq_withs[eq_count - 1]	= CalcBondValue (eq_withs[eq_count], eq_pmt, (prop_config.Int_Rate / 100), ((counter - eq_count) * 12));

					projection[counter].Bond_Amt		+= eq_amt;
					projection[counter].Bond_Pmt		+= eq_pmt;
				}
				if (projection[counter].Bond_Amt <= 0) {
					projection[counter].Bond_Amt		= 0.00;
					projection[counter].Bond_Pmt		= 0.00;
				}
			}
		}
		projection[counter].Gearing_Ratio				= (projection[counter].Bond_Amt / projection[counter].Own_Value) * 100;
		projection[counter].Bond_Pmt					*= 12;
		projection[counter].Rental_Income				= projection[counter - 1].Rental_Income + (projection[counter - 1].Rental_Income * (prop_config.Inf_Rate / 100));
		projection[counter].Vacancy_Amt					= projection[counter].Rental_Income * (prop_config.Vacancy_Rate / 100);
		projection[counter].Maint_Amt					= projection[counter].Rental_Income * (prop_config.Maint_Rate / 100);
		projection[counter].Comm_Amt					= projection[counter].Rental_Income * (prop_config.Comm_Rate / 100);
		projection[counter].Levies						= projection[counter - 1].Levies + (projection[counter - 1].Levies * (prop_config.Inf_Rate / 100));
		projection[counter].Net_Income					= projection[counter].Rental_Income - projection[counter].Vacancy_Amt - projection[counter].Maint_Amt - projection[counter].Comm_Amt - projection[counter].Levies;
		projection[counter].Surplus_Shortfall			= projection[counter].Net_Income - projection[counter].Bond_Pmt;
		projection[counter].Accumulated					= projection[counter - 1].Accumulated + projection[counter].Surplus_Shortfall;
		projection[counter].Equity						= projection[counter].Own_Value - projection[counter].Bond_Amt;
		projection[counter].NROI						= projection[counter].Equity - deal.Deposit - deal.Costs + projection[counter].Surplus_Shortfall;
//		projection[counter].Cashflow          			= (projection[counter].Bond_Amt - deal.Purchase_Price - (deal.Purchase_Price * (prop_config.Transfer_Cost / 100)) - deal.Costs) + (projection[counter].Surplus_Shortfall);
		projection[counter].Cashflow          			= projection[counter - 1].Cashflow + (projection[counter].Surplus_Shortfall);
		if (projection[counter].Cashflow < 0) {
			projection[counter].Acc_ROR					= (projection[counter].NROI / Math.abs (projection[counter].Cashflow)) * 100;
		} else {
			projection[counter].Acc_ROR					= 0.00;
		}
	}
	for (counter = 0; counter < 20; counter++) {
		projection[counter].Provision			= projection[counter + 1].Surplus_Shortfall - prop_config.Refinance_Cost;
		projection[counter].Cash_In_Hand		= eq_withs[counter] + projection[counter].Provision;
	}

	for (counter = 0; counter <= 20; counter++) {
		document.getElementById ('own_value_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Own_Value, 0), 0, 'NT_FLOAT');
		document.getElementById ('bond_amt_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Bond_Amt, 0), 0, 'NT_FLOAT');
		document.getElementById ('bond_pmt_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Bond_Pmt, 0), 0, 'NT_FLOAT');
		document.getElementById ('gearing_ratio_' + counter).innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(prop_config.Gearing, projection[counter].Gearing_Ratio), 1, 'NT_PERC');
		document.getElementById ('rental_income_' + counter).innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Rental_Income, 0), 0, 'NT_FLOAT');
		document.getElementById ('vacancy_amt_' + counter).innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Vacancy_Amt, 0), 0, 'NT_FLOAT');
		document.getElementById ('maint_amt_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Maint_Amt, 0), 0, 'NT_FLOAT');
		document.getElementById ('comm_amt_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Comm_Amt, 0), 0, 'NT_FLOAT');
		document.getElementById ('levies_' + counter).innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Levies, 0), 0, 'NT_FLOAT');
		document.getElementById ('net_income_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Net_Income, 0), 0, 'NT_FLOAT');
		document.getElementById ('ss_' + counter).innerHTML				= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Surplus_Shortfall, 0), 0, 'NT_FLOAT');
		document.getElementById ('accumulated_' + counter).innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Accumulated, 0), 0, 'NT_FLOAT');
		document.getElementById ('equity_' + counter).innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Equity, 0), 0, 'NT_FLOAT');
		document.getElementById ('nroi_' + counter).innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].NROI, 0), 0, 'NT_FLOAT');
		document.getElementById ('cashflow_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Cashflow, 0), 0, 'NT_FLOAT');
		document.getElementById ('acc_ror_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Acc_ROR, 0), 0, 'NT_PERC');
		document.getElementById ('provision_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Provision, 0), 0, 'NT_FLOAT');
		document.getElementById ('cash_' + counter).innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Cash_In_Hand, 0), 0, 'NT_FLOAT');

		if (counter > 0) {
			if ((projection[counter].Gearing_Ratio > prop_config.Gearing) && (eq_withs[counter-1] > 0)) {
				my_form.elements['eq_with_' + (counter - 1)].style.color='#ffffff';
				my_form.elements['eq_with_' + (counter - 1)].style.background='#ff0000';
			} else {
				my_form.elements['eq_with_' + (counter - 1)].style.color='#000000';
				my_form.elements['eq_with_' + (counter - 1)].style.background='#ffffff';
			}
		}
	}
}

function calcPortProjection (deal, prop_config, exchange_rates, target_currency, my_form) {
	// general variables
	var counter			= 0;
	var eq_count		= 0;
	
	// input values
	var eq_withs		= new Array();
	for (counter =0; counter <= 20; counter++) {
		eq_withs[counter]	= parseFloat (unformat_number (my_form.elements['eq_with_' + counter].value, prop_config.Currency_Decimals));
//		eq_withs[counter]	= parseFloat (remove_formatting (my_form.elements['eq_with_' + counter].value));
	}

	// working variables
//	var bond_pmt_pm		= 0.00;
	var eq_with			= 0.00;
	var projection		= new Array();
	var eq_amt			= 0.00;
	var eq_pmt			= 0.00;
//	var cashflow		= 0.00;

	projection[0]					= new Object();
	projection[0].Own_Value			= deal.Own_Valuation;
	projection[0].Bond_Amt			= deal.Bond_Amt;
	if (prop_config.Bond_Type == 0) {
		// interest only loan
		projection[0].Bond_Pmt			= (deal.Bond_Amt * (prop_config.Int_Rate)) / 12;
	} else {
		projection[0].Bond_Pmt			= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -deal.Bond_Amt, 0);
	}
	projection[0].Gearing_Ratio			= (projection[0].Bond_Amt / projection[0].Own_Value) * 100;
	projection[0].Bond_Pmt				*= 12;
	projection[0].Rental_Income			= deal.Rent_PM * 12;

	projection[0].Vacancy_Amt			= projection[0].Rental_Income * (prop_config.Vacancy_Rate / 100);
	projection[0].Maint_Amt				= projection[0].Rental_Income * (prop_config.Maint_Rate / 100);
	projection[0].Comm_Amt				= projection[0].Rental_Income * (prop_config.Comm_Rate / 100);
	projection[0].Levies				= deal.Levies * 12;
	projection[0].Net_Income			= projection[0].Rental_Income - (projection[0].Vacancy_Amt + projection[0].Maint_Amt + projection[0].Comm_Amt + projection[0].Levies);
	projection[0].Surplus_Shortfall		= projection[0].Net_Income - projection[0].Bond_Pmt;
	projection[0].Accumulated			= projection[0].Surplus_Shortfall;
	projection[0].Equity				= projection[0].Own_Value - projection[0].Bond_Amt;
	projection[0].NROI					= projection[0].Equity - deal.Deposit - deal.Costs + projection[0].Surplus_Shortfall;
//	cashflow							= (deal.Bond_Amt - deal.Purchase_Price - deal.Costs) + (projection[0].Surplus_Shortfall);
	projection[0].Cashflow				= (deal.Bond_Amt - deal.Purchase_Price - deal.Costs) + projection[0].Surplus_Shortfall;
	if (projection[0].Cashflow < 0) {
		projection[0].Acc_ROR			= (projection[0].NROI / Math.abs (projection[0].Cashflow)) * 100;
	} else {
		projection[0].Acc_ROR			= 0.00;
	}

	projection[1]		= new Object();
	projection[1].Own_Value			= (deal.Own_Valuation * (prop_config.Growth_Rate / 100)) + deal.Own_Valuation;
	if (prop_config.Bond_Type == 0) {
		// interest only loan
//		projection[1].Bond_Amt			= deal.Bond_Amt;
//		bond_pmt_pm		= (bond_amt * (prop_config.Int_Rate / 100)) / 12;
//		projection[1].Bond_Pmt			= (deal.Bond_Amt * (prop_config.Int_Rate / 100)) / 12;

		eq_with = 0.00;
		for (eq_count = 0; eq_count < 1; eq_count++) {
			if (eq_count >= (1 - prop_config.Bond_Term)) {
				eq_with += eq_withs[eq_count];
			}
		}
		if (1 >= prop_config.Bond_Term) {
			projection[1].Bond_Amt = eq_with;
		} else {
			projection[1].Bond_Amt = deal.Bond_Amt + eq_with;
		}
		projection[1].Bond_Pmt = (projection[1].Bond_Amt * (prop_config.Int_Rate / 100)) / 12;
	} else {
		// normal loan
//		projection[1].Bond_Pmt			= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -deal.Bond_Amt, 0);
//		projection[1].Bond_Amt			= CalcBondValue (deal.Bond_Amt, projection[1].Bond_Pmt, (prop_config.Int_Rate / 100), 12);

		projection[1].Bond_Pmt			= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -deal.Bond_Amt, 0);
		projection[1].Bond_Amt			= CalcBondValue (deal.Bond_Amt, projection[1].Bond_Pmt, (prop_config.Int_Rate / 100), 12);

		for (eq_count = 0; eq_count < 1; eq_count++) {
			if (eq_withs[eq_count] > 0) {
                eq_pmt					= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -eq_withs[eq_count], 0);
                eq_amt					= CalcBondValue (eq_withs[eq_count], eq_pmt, (prop_config.Int_Rate / 100), ((1 - eq_count) * 12));
//                    eq_withs[eq_count - 1]	= CalcBondValue (eq_withs[eq_count], eq_pmt, (prop_config.Int_Rate / 100), ((1 - eq_count) * 12));

				projection[1].Bond_Amt		+= eq_amt;
				projection[1].Bond_Pmt		+= eq_pmt;
			}
			if (projection[1].Bond_Amt <= 0) {
				projection[1].Bond_Amt		= 0.00;
				projection[1].Bond_Pmt		= 0.00;
			}
		}
	}
	projection[1].Gearing_Ratio			= (projection[1].Bond_Amt / projection[1].Own_Value) * 100;
	projection[1].Bond_Pmt				*= 12;
	projection[1].Rental_Income			= deal.Rent_PM * 12;
	projection[1].Vacancy_Amt			= projection[1].Rental_Income * (prop_config.Vacancy_Rate / 100);
	projection[1].Maint_Amt				= projection[1].Rental_Income * (prop_config.Maint_Rate / 100);
	projection[1].Comm_Amt				= projection[1].Rental_Income * (prop_config.Comm_Rate / 100);
	projection[1].Levies				= deal.Levies * 12;
	projection[1].Net_Income			= projection[1].Rental_Income - projection[1].Vacancy_Amt - projection[1].Maint_Amt - projection[1].Comm_Amt - projection[1].Levies;
	projection[1].Surplus_Shortfall		= projection[1].Net_Income - projection[1].Bond_Pmt;
	projection[1].Accumulated			= projection[1].Surplus_Shortfall;
	projection[1].Equity				= projection[1].Own_Value - projection[1].Bond_Amt;
	projection[1].NROI					= projection[1].Equity - deal.Deposit - deal.Costs + projection[1].Surplus_Shortfall;
	projection[1].Cashflow				= (deal.Bond_Amt - deal.Purchase_Price - (deal.Purchase_Price * (prop_config.Transfer_Cost / 100)) - deal.Costs) + (projection[1].Surplus_Shortfall);
//	cashflow							= (deal.Bond_Amt - deal.Purchase_Price - (deal.Purchase_Price * (prop_config.Transfer_Cost / 100)) - deal.Costs) + (projection[1].Surplus_Shortfall);
	if (projection[1].Cashflow < 0) {
		projection[1].Acc_ROR			= (projection[1].NROI / Math.abs (projection[1].Cashflow)) * 100;
	} else {
		projection[1].Acc_ROR			= 0.00;
	}

	for (counter = 2; counter <= 20; counter++) {
		projection[counter]					= new Object();
 		projection[counter].Own_Value		= (projection[counter - 1].Own_Value * (prop_config.Growth_Rate / 100)) + projection[counter - 1].Own_Value;
		if (prop_config.Bond_Type == 0) {
			eq_with = 0.00;
			for (eq_count = 0; eq_count < counter; eq_count++) {
				if (eq_count >= (counter - prop_config.Bond_Term)) {
					eq_with += eq_withs[eq_count];
				}
			}
			if (counter >= prop_config.Bond_Term) {
				projection[counter].Bond_Amt = eq_with;
			} else {
				projection[counter].Bond_Amt = deal.Bond_Amt + eq_with;
			}
			projection[counter].Bond_Pmt = (projection[counter].Bond_Amt * (prop_config.Int_Rate / 100)) / 12;
		} else {
			projection[counter].Bond_Pmt	= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -deal.Bond_Amt, 0);
			projection[counter].Bond_Amt	= CalcBondValue (deal.Bond_Amt, projection[counter].Bond_Pmt, (prop_config.Int_Rate / 100), (counter * 12));

			for (eq_count = 0; eq_count < counter; eq_count++) {
				if (eq_withs[eq_count] > 0) {
                    eq_pmt					= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -eq_withs[eq_count], 0);
                    eq_amt					= CalcBondValue (eq_withs[eq_count], eq_pmt, (prop_config.Int_Rate / 100), ((counter - eq_count) * 12));
//                    eq_withs[eq_count - 1]	= CalcBondValue (eq_withs[eq_count], eq_pmt, (prop_config.Int_Rate / 100), ((counter - eq_count) * 12));

					projection[counter].Bond_Amt		+= eq_amt;
					projection[counter].Bond_Pmt		+= eq_pmt;
				}
				if (projection[counter].Bond_Amt <= 0) {
					projection[counter].Bond_Amt		= 0.00;
					projection[counter].Bond_Pmt		= 0.00;
				}
			}
		}
		projection[counter].Gearing_Ratio				= (projection[counter].Bond_Amt / projection[counter].Own_Value) * 100;
		projection[counter].Bond_Pmt					*= 12;
		projection[counter].Rental_Income				= projection[counter - 1].Rental_Income + (projection[counter - 1].Rental_Income * (prop_config.Inf_Rate / 100));
		projection[counter].Vacancy_Amt					= projection[counter].Rental_Income * (prop_config.Vacancy_Rate / 100);
		projection[counter].Maint_Amt					= projection[counter].Rental_Income * (prop_config.Maint_Rate / 100);
		projection[counter].Comm_Amt					= projection[counter].Rental_Income * (prop_config.Comm_Rate / 100);
		projection[counter].Levies						= projection[counter - 1].Levies + (projection[counter - 1].Levies * (prop_config.Inf_Rate / 100));
		projection[counter].Net_Income					= projection[counter].Rental_Income - projection[counter].Vacancy_Amt - projection[counter].Maint_Amt - projection[counter].Comm_Amt - projection[counter].Levies;
		projection[counter].Surplus_Shortfall			= projection[counter].Net_Income - projection[counter].Bond_Pmt;
		projection[counter].Accumulated					= projection[counter - 1].Accumulated + projection[counter].Surplus_Shortfall;
		projection[counter].Equity						= projection[counter].Own_Value - projection[counter].Bond_Amt;
		projection[counter].NROI						= projection[counter].Equity - deal.Deposit - deal.Costs + projection[counter].Surplus_Shortfall;
//		projection[counter].Cashflow          			= (projection[counter].Bond_Amt - deal.Purchase_Price - (deal.Purchase_Price * (prop_config.Transfer_Cost / 100)) - deal.Costs) + (projection[counter].Surplus_Shortfall);
		projection[counter].Cashflow          			= projection[counter - 1].Cashflow + (projection[counter].Surplus_Shortfall);
		if (projection[counter].Cashflow < 0) {
			projection[counter].Acc_ROR					= (projection[counter].NROI / Math.abs (projection[counter].Cashflow)) * 100;
		} else {
			projection[counter].Acc_ROR					= 0.00;
		}
	}
	for (counter = 0; counter < 20; counter++) {
		projection[counter].Provision			= projection[counter + 1].Surplus_Shortfall - prop_config.Refinance_Cost;
		projection[counter].Cash_In_Hand		= eq_withs[counter] + projection[counter].Provision;
	}

	for (counter = 0; counter <= 20; counter++) {
		document.getElementById ('own_value_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Own_Value, 0), 0, 'NT_FLOAT');
		document.getElementById ('bond_amt_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Bond_Amt, 0), 0, 'NT_FLOAT');
		document.getElementById ('bond_pmt_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Bond_Pmt, 0), 0, 'NT_FLOAT');
		document.getElementById ('gearing_ratio_' + counter).innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(prop_config.Gearing, projection[counter].Gearing_Ratio), 1, 'NT_PERC');
		document.getElementById ('rental_income_' + counter).innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Rental_Income, 0), 0, 'NT_FLOAT');
		document.getElementById ('vacancy_amt_' + counter).innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Vacancy_Amt, 0), 0, 'NT_FLOAT');
		document.getElementById ('maint_amt_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Maint_Amt, 0), 0, 'NT_FLOAT');
		document.getElementById ('comm_amt_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Comm_Amt, 0), 0, 'NT_FLOAT');
		document.getElementById ('levies_' + counter).innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Levies, 0), 0, 'NT_FLOAT');
		document.getElementById ('net_income_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Net_Income, 0), 0, 'NT_FLOAT');
		document.getElementById ('ss_' + counter).innerHTML				= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Surplus_Shortfall, 0), 0, 'NT_FLOAT');
		document.getElementById ('accumulated_' + counter).innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Accumulated, 0), 0, 'NT_FLOAT');
		document.getElementById ('equity_' + counter).innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Equity, 0), 0, 'NT_FLOAT');
		document.getElementById ('nroi_' + counter).innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].NROI, 0), 0, 'NT_FLOAT');
		document.getElementById ('cashflow_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Cashflow, 0), 0, 'NT_FLOAT');
		document.getElementById ('acc_ror_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Acc_ROR, 0), 0, 'NT_PERC');
		document.getElementById ('provision_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Provision, 0), 0, 'NT_FLOAT');
		document.getElementById ('cash_' + counter).innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Cash_In_Hand, 0), 0, 'NT_FLOAT');

		if (counter > 0) {
			if ((projection[counter].Gearing_Ratio > prop_config.Gearing) && (eq_withs[counter-1] > 0)) {
				my_form.elements['eq_with_' + (counter - 1)].style.color='#ffffff';
				my_form.elements['eq_with_' + (counter - 1)].style.background='#ff0000';
			} else {
				my_form.elements['eq_with_' + (counter - 1)].style.color='#000000';
				my_form.elements['eq_with_' + (counter - 1)].style.background='#ffffff';
			}
		}
	}
}

function calcHistoryProjection (property, prop_config, exchange_rates, target_currency, my_form) {
	var purchase_year	= property.PurchaseYear;		// add thios property to calling page's object
	var current_year	= new Date().getFullYear();
	var end_year		= purchase_year + 19;
	var year_counter	= purchase_year;

	var projection		= new Array();
	var years			= new Array();

	var eq_with			= 0.00;
	var eq_count		= 0;
	var eq_amt			= 0.00;
	var eq_pmt			= 0.00;

	for (counter = purchase_year; counter <= current_year; counter++) {
		years[counter]					= new Object();
		years[counter].Own_Value		= parseFloat (unformat_number (my_form.elements['own_value_' + counter].value, prop_config.Currency_Decimals));
		years[counter].Bond_Amt			= parseFloat (unformat_number (my_form.elements['bond_amt_' + counter].value, prop_config.Currency_Decimals));
		years[counter].Bond_Pmt			= parseFloat (unformat_number (my_form.elements['bond_pmt_' + counter].value, prop_config.Currency_Decimals));
		years[counter].Rental_Income	= parseFloat (unformat_number (my_form.elements['rental_income_' + counter].value, prop_config.Currency_Decimals));
		years[counter].Vacancy_Amt		= parseFloat (unformat_number (my_form.elements['vacancy_amt_' + counter].value, prop_config.Currency_Decimals));
		years[counter].Maint_Amt		= parseFloat (unformat_number (my_form.elements['maint_amt_' + counter].value, prop_config.Currency_Decimals));
		years[counter].Comm_Amt			= parseFloat (unformat_number (my_form.elements['comm_amt_' + counter].value, prop_config.Currency_Decimals));
		years[counter].Levies			= parseFloat (unformat_number (my_form.elements['levies_' + counter].value, prop_config.Currency_Decimals));
		years[counter].Eq_With			= parseFloat (unformat_number (my_form.elements['eq_with_' + counter].value, prop_config.Currency_Decimals));
	}

	year						= new Object();
	year.Own_Value				= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Own_Value : property.Own_Valuation;
	year.Bond_Amt				= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Bond_Amt : property.Bond_Amt;
	if (typeof(years[year_counter]) != "undefined") {
		year.Bond_Pmt			= years[year_counter].Bond_Pmt;
	} else {
		if (prop_config.Bond_Type == 0) {
			year.Bond_Pmt		= (property.Bond_Amt * (prop_config.Int_Rate)) / 12;
		} else {
			year.Bond_Pmt		= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -property.Bond_Amt, 0);
		}
		year.Bond_Pmt			*= 12;
	}
	year.Gearing_Ratio		= (year.Bond_Amt / year.Own_Value) * 100;
	year.Rental_Income		= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Rental_Income : (property.Rent_PM * 12);
	year.Vacancy_Amt		= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Vacancy_Amt : (year.Rental_Income * (prop_config.Vacancy_Rate / 100));
	year.Maint_Amt			= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Maint_Amt : (year.Rental_Income * (prop_config.Maint_Rate / 100));
	year.Comm_Amt			= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Comm_Amt : (year.Rental_Income * (prop_config.Comm_Rate / 100));
	year.Levies				= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Levies : (property.Levies * 12);
	year.Net_Income			= year.Rental_Income - (year.Vacancy_Amt + year.Maint_Amt + year.Comm_Amt + year.Levies);
	year.Surplus_Shortfall	= year.Net_Income - year.Bond_Pmt;
	year.Accumulated		= year.Surplus_Shortfall;
	year.Equity				= year.Own_Value - year.Bond_Amt;
	year.NROI					= year.Equity - property.Deposit - property.Costs + year.Surplus_Shortfall;
	year.Cashflow				= (property.Bond_Amt - property.Purchase_Price - property.Costs) + year.Surplus_Shortfall;
	if (year.Cashflow < 0) {
		year.Acc_ROR			= (year.NROI / Math.abs (year.Cashflow)) * 100;
	} else {
		year.Acc_ROR			= 0.00;
	}
	projection[year_counter]					= year;

	year_counter++;
	if (year_counter <= current_year) {
		year						= new Object();
		year.Own_Value				= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Own_Value : ((property.Own_Valuation * (prop_config.Growth_Rate / 100)) + property.Own_Valuation);
		if (typeof(years[year_counter]) != "undefined") {
			year.Bond_Amt			= years[year_counter].Bond_Amt;
			year.Bond_Pmt			= years[year_counter].Bond_Pmt;
		} else {
			if (prop_config.Bond_Type == 0) {
				eq_with = (typeof(years[purchase_year]) != "undefined") ? years[purchase_year].Eq_With : 0.00;
				year.Bond_Amt = property.Bond_Amt + eq_with;
				year.Bond_Pmt = (year.Bond_Amt * (prop_config.Int_Rate / 100)) / 12;
			} else {
				year.Bond_Pmt			= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -property.Bond_Amt, 0);
				year.Bond_Amt			= CalcBondValue (property.Bond_Amt, year.Bond_Pmt, (prop_config.Int_Rate / 100), 12);
	
				if ((typeof(years[purchase_year]) != "undefined") && (years[purchase_year].Eq_With > 0)) {
		            eq_pmt				= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -years[purchase_year].Eq_With, 0);
		            eq_amt				= CalcBondValue (years[purchase_year].Eq_With, eq_pmt, (prop_config.Int_Rate / 100), 12);
					year.Bond_Amt		+= eq_amt;
					year.Bond_Pmt		+= eq_pmt;
				}
				if (year.Bond_Amt <= 0) {
					year.Bond_Amt		= 0.00;
					year.Bond_Pmt		= 0.00;
				}
			}
			year.Bond_Pmt				*= 12;
		}
		year.Gearing_Ratio		= (year.Bond_Amt / year.Own_Value) * 100;
		year.Rental_Income		= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Rental_Income : (property.Rent_PM * 12);
		year.Vacancy_Amt		= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Vacancy_Amt : (year.Rental_Income * (prop_config.Vacancy_Rate / 100));
		year.Maint_Amt			= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Maint_Amt : (year.Rental_Income * (prop_config.Maint_Rate / 100));
		year.Comm_Amt			= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Comm_Amt : (year.Rental_Income * (prop_config.Comm_Rate / 100));
		year.Levies				= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Levies : (property.Levies * 12);
		year.Net_Income			= year.Rental_Income - (year.Vacancy_Amt + year.Maint_Amt + year.Comm_Amt + year.Levies);
		year.Surplus_Shortfall	= year.Net_Income - year.Bond_Pmt;
		year.Accumulated		= year.Surplus_Shortfall;
		year.Equity				= year.Own_Value - year.Bond_Amt;
		year.NROI				= year.Equity - property.Deposit - property.Costs + year.Surplus_Shortfall;
		year.Cashflow			= (property.Bond_Amt - property.Purchase_Price - (property.Purchase_Price * (prop_config.Transfer_Cost / 100)) - property.Costs) + (year.Surplus_Shortfall);
		if (year.Cashflow < 0) {
			year.Acc_ROR			= (year.NROI / Math.abs (year.Cashflow)) * 100;
		} else {
			year.Acc_ROR			= 0.00;
		}
		projection[year_counter]					= year;
	}

	for (year_counter = year_counter; year_counter <= current_year; year_counter++) {
		year						= new Object();
		year.Own_Value				= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Own_Value : ((projection[year_counter - 1].Own_Value * (prop_config.Growth_Rate / 100)) + property.Own_Valuation);
		if (typeof(years[year_counter]) != "undefined") {
			year.Bond_Amt			= years[year_counter].Bond_Amt;
			year.Bond_Pmt			= years[year_counter].Bond_Pmt;
		} else {
			if (prop_config.Bond_Type == 0) {
				eq_with = 0.00;
				for (eq_count = purchase_year; eq_count < year_counter; eq_count++) {
					if (eq_count >= (year_counter - prop_config.Bond_Term)) {
						eq_with += (typeof(years[eq_count]) != "undefined") ? years[eq_count].Eq_With : 0.00;
					}
				}
				if (year_counter >= prop_config.Bond_Term) {
					year.Bond_Amt = eq_with;
				} else {
					year.Bond_Amt = property.Bond_Amt + eq_with;
				}
				year.Bond_Pmt = (year.Bond_Amt * (prop_config.Int_Rate / 100)) / 12;
			} else {
				year.Bond_Pmt	= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -property.Bond_Amt, 0);
				year.Bond_Amt	= CalcBondValue (property.Bond_Amt, year.Bond_Pmt, (prop_config.Int_Rate / 100), (year_counter * 12));
	
				for (eq_count = 0; eq_count < year_counter; eq_count++) {
					if ((typeof(years[eq_count]) != "undefined") && (years[eq_count].Eq_With > 0)) {
	                    eq_pmt					= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -years[eq_count].Eq_With, 0);
	                    eq_amt					= CalcBondValue (years[eq_count].Eq_With, eq_pmt, (prop_config.Int_Rate / 100), ((year_counter - eq_count) * 12));
						year.Bond_Amt			+= eq_amt;
						year.Bond_Pmt			+= eq_pmt;
					}
					if (year.Bond_Amt <= 0) {
						year.Bond_Amt		= 0.00;
						year.Bond_Pmt		= 0.00;
					}
				}
			}
			year.Bond_Pmt					*= 12;
		}
		year.Gearing_Ratio		= (year.Bond_Amt / year.Own_Value) * 100;
		year.Rental_Income		= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Rental_Income : (projection[year_counter - 1].Rental_Income + (projection[year_counter - 1].Rental_Income * (prop_config.Inf_Rate / 100)));
		year.Vacancy_Amt		= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Vacancy_Amt : (year.Rental_Income * (prop_config.Vacancy_Rate / 100));
		year.Maint_Amt			= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Maint_Amt : (year.Rental_Income * (prop_config.Maint_Rate / 100));
		year.Comm_Amt			= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Comm_Amt : (year.Rental_Income * (prop_config.Comm_Rate / 100));
		year.Levies				= (typeof(years[year_counter]) != "undefined") ? years[year_counter].Levies : (projection[year_counter - 1].Levies + (projection[year_counter - 1].Levies * (prop_config.Inf_Rate / 100)));
		year.Net_Income			= year.Rental_Income - (year.Vacancy_Amt + year.Maint_Amt + year.Comm_Amt + year.Levies);
		year.Surplus_Shortfall	= year.Net_Income - year.Bond_Pmt;
		year.Accumulated		= projection[year_counter - 1].Accumulated + year.Surplus_Shortfall;
		year.Equity				= year.Own_Value - year.Bond_Amt;
		year.NROI				= year.Equity - property.Deposit - property.Costs + year.Surplus_Shortfall;
		year.Cashflow			= projection[year_counter - 1].Cashflow + (year.Surplus_Shortfall);
		if (year.Cashflow < 0) {
			year.Acc_ROR			= (year.NROI / Math.abs (year.Cashflow)) * 100;
		} else {
			year.Acc_ROR			= 0.00;
		}
		projection[year_counter]					= year;
	}
	for (year_counter = purchase_year; year_counter < current_year; year_counter++) {
		projection[year_counter].Provision			= projection[year_counter + 1].Surplus_Shortfall - prop_config.Refinance_Cost;
		projection[year_counter].Cash_In_Hand		= years[year_counter].Eq_With + projection[year_counter].Provision;
	}

	for (counter = purchase_year; counter <= current_year; counter++) {
		if (counter <= current_year) {
			my_form.elements ['own_value_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Own_Value, 'NT_FLOAT')
			my_form.elements ['bond_amt_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Bond_Amt, 'NT_FLOAT')
			my_form.elements ['bond_pmt_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Bond_Pmt, 'NT_FLOAT')
			my_form.elements ['rental_income_' + counter].value		= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Rental_Income, 'NT_FLOAT')
			my_form.elements ['vacancy_amt_' + counter].value		= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Vacancy_Amt, 'NT_FLOAT')
			my_form.elements ['maint_amt_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Maint_Amt, 'NT_FLOAT')
			my_form.elements ['comm_amt_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Comm_Amt, 'NT_FLOAT')
			my_form.elements ['levies_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Levies, 'NT_FLOAT')
		} else {
			document.getElementById ('own_value_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Own_Value, 0), 0, 'NT_FLOAT');
			document.getElementById ('bond_amt_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Bond_Amt, 0), 0, 'NT_FLOAT');
			document.getElementById ('bond_pmt_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Bond_Pmt, 0), 0, 'NT_FLOAT');
			document.getElementById ('rental_income_' + counter).innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Rental_Income, 0), 0, 'NT_FLOAT');
			document.getElementById ('vacancy_amt_' + counter).innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Vacancy_Amt, 0), 0, 'NT_FLOAT');
			document.getElementById ('maint_amt_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Maint_Amt, 0), 0, 'NT_FLOAT');
			document.getElementById ('comm_amt_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Comm_Amt, 0), 0, 'NT_FLOAT');
			document.getElementById ('levies_' + counter).innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Levies, 0), 0, 'NT_FLOAT');
		}
		document.getElementById ('gearing_ratio_' + counter).innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(prop_config.Gearing, projection[counter].Gearing_Ratio), 1, 'NT_PERC');
		document.getElementById ('net_income_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Net_Income, 0), 0, 'NT_FLOAT');
		document.getElementById ('ss_' + counter).innerHTML				= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Surplus_Shortfall, 0), 0, 'NT_FLOAT');
		document.getElementById ('accumulated_' + counter).innerHTML	= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Accumulated, 0), 0, 'NT_FLOAT');
		document.getElementById ('equity_' + counter).innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Equity, 0), 0, 'NT_FLOAT');
		document.getElementById ('nroi_' + counter).innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].NROI, 0), 0, 'NT_FLOAT');
		document.getElementById ('cashflow_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Cashflow, 0), 0, 'NT_FLOAT');
		document.getElementById ('acc_ror_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Acc_ROR, 0), 0, 'NT_PERC');
		document.getElementById ('provision_' + counter).innerHTML		= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Provision, 0), 0, 'NT_FLOAT');
		document.getElementById ('cash_' + counter).innerHTML			= FormatDisplay (prop_config, target_currency, exchange_rates, new Array(projection[counter].Cash_In_Hand, 0), 0, 'NT_FLOAT');
	}
}

function calcPropProjection2 (property, prop_config, exchange_rates, target_currency, my_form) {
	// general variables
	var counter			= 0;
	var eq_count		= 0;
	
	// input values
	var eq_withs		= new Array();
	for (counter = property.CurrentYear; counter < (property.CurrentYear + 20); counter++) {
		eq_withs[counter]	= parseFloat (unformat_number (my_form.elements['eq_with_' + counter].value, prop_config.Currency_Decimals));
	}

	// working variables
	var eq_with			= 0.00;
	var projection		= new Array();
	var eq_amt			= 0.00;
	var eq_pmt			= 0.00;

	projection[0]						= new Object();
	projection[0].Own_Value			= property.Own_Valuation;
	projection[0].Bond_Amt			= property.Bond_Amt;
	if (prop_config.Bond_Type == 0) {
		projection[0].Bond_Pmt		= (property.Bond_Amt * (prop_config.Int_Rate)) / 12;
	} else {
		projection[0].Bond_Pmt		= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -property.Bond_Amt, 0);
	}
	projection[0].Gearing_Ratio		= (projection[0].Bond_Amt / projection[0].Own_Value) * 100;
	projection[0].Bond_Pmt			*= 12;
	projection[0].Rental_Income		= property.Rent_PM * 12;
	projection[0].Vacancy_Amt			= projection[0].Rental_Income * (prop_config.Vacancy_Rate / 100);
	projection[0].Maint_Amt			= projection[0].Rental_Income * (prop_config.Maint_Rate / 100);
	projection[0].Comm_Amt			= projection[0].Rental_Income * (prop_config.Comm_Rate / 100);
	projection[0].Levies				= property.Levies * 12;

	projection[0].Net_Income			= projection[0].Rental_Income - (projection[0].Vacancy_Amt + projection[0].Maint_Amt + projection[0].Comm_Amt + projection[0].Levies);
	projection[0].Surplus_Shortfall	= projection[0].Net_Income - projection[0].Bond_Pmt;

	projection[0].Accumulated			= projection[0].Surplus_Shortfall;
	projection[0].Equity				= projection[0].Own_Value - projection[0].Bond_Amt;
	projection[0].NROI				= projection[0].Equity - property.Deposit - property.Costs + projection[0].Surplus_Shortfall;
	projection[0].Cashflow			= (property.Bond_Amt - property.Purchase_Price - property.Costs) + projection[0].Surplus_Shortfall;
	if (projection[0].Cashflow < 0) {
		projection[0].Acc_ROR			= (projection[0].NROI / Math.abs (projection[0].Cashflow)) * 100;
	} else {
		projection[0].Acc_ROR			= 0.00;
	}

	counter = property.CurrentYear;
	projection[counter]						= new Object();
	projection[counter].Own_Value			= (property.Own_Valuation * (prop_config.Growth_Rate / 100)) + property.Own_Valuation;
	if (prop_config.Bond_Type == 0) {
		eq_with = 0.00;
		for (eq_count = property.CurrentYear; eq_count < (property.CurrentYear + 1); eq_count++) { if (eq_count >= (1 - prop_config.Bond_Term)) { eq_with += eq_withs[eq_count]; } }
		if (1 >= prop_config.Bond_Term) { projection[counter].Bond_Amt = eq_with; } else { projection[counter].Bond_Amt = property.Bond_Amt + eq_with; }
		projection[counter].Bond_Pmt = (projection[counter].Bond_Amt * (prop_config.Int_Rate / 100)) / 12;
	} else {
		projection[counter].Bond_Pmt			= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -property.Bond_Amt, 0);
		projection[counter].Bond_Amt			= CalcBondValue (property.Bond_Amt, projection[counter].Bond_Pmt, (prop_config.Int_Rate / 100), 12);

		for (eq_count = property.CurrentYear; eq_count < (property.CurrentYear + 1); eq_count++) {
			if (eq_withs[eq_count] > 0) {
                eq_pmt					= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -eq_withs[eq_count], 0);
                eq_amt					= CalcBondValue (eq_withs[eq_count], eq_pmt, (prop_config.Int_Rate / 100), ((1 - eq_count) * 12));

				projection[counter].Bond_Amt		+= eq_amt;
				projection[counter].Bond_Pmt		+= eq_pmt;
			}
			if (projection[counter].Bond_Amt <= 0) {
				projection[counter].Bond_Amt		= 0.00;
				projection[counter].Bond_Pmt		= 0.00;
			}
		}
	}
	projection[counter].Gearing_Ratio			= (projection[counter].Bond_Amt / projection[counter].Own_Value) * 100;
	projection[counter].Bond_Pmt				*= 12;
	projection[counter].Rental_Income			= property.Rent_PM * 12;
	projection[counter].Vacancy_Amt				= projection[counter].Rental_Income * (prop_config.Vacancy_Rate / 100);
	projection[counter].Maint_Amt				= projection[counter].Rental_Income * (prop_config.Maint_Rate / 100);
	projection[counter].Comm_Amt				= projection[counter].Rental_Income * (prop_config.Comm_Rate / 100);
	projection[counter].Levies					= property.Levies * 12;
	projection[counter].Net_Income				= projection[counter].Rental_Income - projection[counter].Vacancy_Amt - projection[counter].Maint_Amt - projection[counter].Comm_Amt - projection[counter].Levies;
	projection[counter].Surplus_Shortfall		= projection[counter].Net_Income - projection[counter].Bond_Pmt;
	projection[counter].Accumulated				= projection[counter].Surplus_Shortfall;
	projection[counter].Equity					= projection[counter].Own_Value - projection[counter].Bond_Amt;
	projection[counter].NROI					= projection[counter].Equity - property.Deposit - property.Costs + projection[counter].Surplus_Shortfall;
	projection[counter].Cashflow				= (property.Bond_Amt - property.Purchase_Price - (property.Purchase_Price * (prop_config.Transfer_Cost / 100)) - property.Costs) + (projection[counter].Surplus_Shortfall);
	if (projection[counter].Cashflow < 0) {
		projection[counter].Acc_ROR				= (projection[counter].NROI / Math.abs (projection[counter].Cashflow)) * 100;
	} else {
		projection[counter].Acc_ROR				= 0.00;
	}

	counter++;
	for (counter = counter; counter <= (property.CurrentYear + 20); counter++) {
		projection[counter]						= new Object();
 		projection[counter].Own_Value			= (projection[counter - 1].Own_Value * (prop_config.Growth_Rate / 100)) + projection[counter - 1].Own_Value;

		if (prop_config.Bond_Type == 0) {
			eq_with = 0.00;
			for (eq_count = property.CurrentYear; eq_count < counter; eq_count++) { if (eq_count >= (counter - prop_config.Bond_Term)) { eq_with += eq_withs[eq_count]; } }
			if (counter >= prop_config.Bond_Term) { projection[counter].Bond_Amt = eq_with; } else { projection[counter].Bond_Amt = property.Bond_Amt + eq_with; }
			projection[counter].Bond_Pmt = (projection[counter].Bond_Amt * (prop_config.Int_Rate / 100)) / 12;
		} else {
			projection[counter].Bond_Pmt	= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -property.Bond_Amt, 0);
			projection[counter].Bond_Amt	= CalcBondValue (property.Bond_Amt, projection[counter].Bond_Pmt, (prop_config.Int_Rate / 100), (((counter - property.CurrentYear) + 1) * 12));

			for (eq_count = property.CurrentYear; eq_count < counter; eq_count++) {
				if (eq_withs[eq_count] > 0) {
                    eq_pmt					= Payment (prop_config.Int_Rate, (prop_config.Bond_Term * 12), -eq_withs[eq_count], 0);
                    eq_amt					= CalcBondValue (eq_withs[eq_count], eq_pmt, (prop_config.Int_Rate / 100), ((counter - eq_count) * 12));

					projection[counter].Bond_Amt		+= eq_amt;
					projection[counter].Bond_Pmt		+= eq_pmt;
				}
				if (projection[counter].Bond_Amt <= 0) {
					projection[counter].Bond_Amt		= 0.00;
					projection[counter].Bond_Pmt		= 0.00;
				}
			}
		}
		projection[counter].Gearing_Ratio				= (projection[counter].Bond_Amt / projection[counter].Own_Value) * 100;
		projection[counter].Bond_Pmt					*= 12;
		projection[counter].Rental_Income				= projection[counter - 1].Rental_Income + (projection[counter - 1].Rental_Income * (prop_config.Inf_Rate / 100));
		projection[counter].Vacancy_Amt					= projection[counter].Rental_Income * (prop_config.Vacancy_Rate / 100);
		projection[counter].Maint_Amt					= projection[counter].Rental_Income * (prop_config.Maint_Rate / 100);
		projection[counter].Comm_Amt					= projection[counter].Rental_Income * (prop_config.Comm_Rate / 100);
		projection[counter].Levies						= projection[counter - 1].Levies + (projection[counter - 1].Levies * (prop_config.Inf_Rate / 100));
		projection[counter].Net_Income					= projection[counter].Rental_Income - projection[counter].Vacancy_Amt - projection[counter].Maint_Amt - projection[counter].Comm_Amt - projection[counter].Levies;
		projection[counter].Surplus_Shortfall			= projection[counter].Net_Income - projection[counter].Bond_Pmt;
		projection[counter].Accumulated					= projection[counter - 1].Accumulated + projection[counter].Surplus_Shortfall;
		projection[counter].Equity						= projection[counter].Own_Value - projection[counter].Bond_Amt;
		projection[counter].NROI						= projection[counter].Equity - property.Deposit - property.Costs + projection[counter].Surplus_Shortfall;
		projection[counter].Cashflow          			= projection[counter - 1].Cashflow + (projection[counter].Surplus_Shortfall);
		if (projection[counter].Cashflow < 0) {
			projection[counter].Acc_ROR					= (projection[counter].NROI / Math.abs (projection[counter].Cashflow)) * 100;
		} else {
			projection[counter].Acc_ROR					= 0.00;
		}
	}

	for (counter = property.CurrentYear; counter < (property.CurrentYear + 20); counter++) {
		projection[counter].Provision			= projection[counter + 1].Surplus_Shortfall - prop_config.Refinance_Cost;
		projection[counter].Cash_In_Hand		= eq_withs[counter] + projection[counter].Provision;
	}

	my_form.elements['gearing_ratio'].value		= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[0].Gearing_Ratio, 'NT_PERC');
	my_form.elements['bond_pmt'].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[0].Bond_Pmt, 0, 'NT_FLOAT');
	my_form.elements['vacancy_amt'].value		= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[0].Vacancy_Amt, 0, 'NT_FLOAT');
	my_form.elements['maint_amt'].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[0].Maint_Amt, 0, 'NT_FLOAT');
	my_form.elements['comm_amt'].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[0].Comm_Amt, 0, 'NT_FLOAT');
	my_form.elements['net_income'].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[0].Net_Income, 0, 'NT_FLOAT');
	my_form.elements['ss'].value					= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[0].Surplus_Shortfall, 0, 'NT_FLOAT');
	my_form.elements['equity'].value				= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[0].Equity, 0, 'NT_FLOAT');
	my_form.elements['nroi'].value				= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[0].NROI, 0, 'NT_FLOAT');
	my_form.elements['cashflow'].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[0].Cashflow, 0, 'NT_FLOAT');

	counter = property.CurrentYear;
	my_form.elements['own_value_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Own_Value, 'NT_FLOAT');
	my_form.elements['bond_amt_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Bond_Amt, 'NT_FLOAT');
	my_form.elements['gearing_ratio_' + counter].value		= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Gearing_Ratio, 'NT_PERC');
	my_form.elements['bond_pmt_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Bond_Pmt, 0, 'NT_FLOAT');
	my_form.elements['rental_income_' + counter].value		= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Rental_Income, 'NT_FLOAT');
	my_form.elements['vacancy_amt_' + counter].value		= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Vacancy_Amt, 0, 'NT_FLOAT');
	my_form.elements['maint_amt_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Maint_Amt, 0, 'NT_FLOAT');
	my_form.elements['comm_amt_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Comm_Amt, 0, 'NT_FLOAT');
	my_form.elements['levies_' + counter].value				= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Levies, 'NT_FLOAT');
	my_form.elements['net_income_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Net_Income, 0, 'NT_FLOAT');
	my_form.elements['ss_' + counter].value					= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Surplus_Shortfall, 0, 'NT_FLOAT');
	my_form.elements['accumulated_' + counter].value		= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Accumulated, 0, 'NT_FLOAT');
	my_form.elements['equity_' + counter].value				= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Equity, 0, 'NT_FLOAT');
	my_form.elements['nroi_' + counter].value				= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].NROI, 0, 'NT_FLOAT');
	my_form.elements['cashflow_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Cashflow, 0, 'NT_FLOAT');
	my_form.elements['acc_ror_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Acc_ROR, 0, 'NT_PERC');
	my_form.elements['provision_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Provision, 0, 'NT_FLOAT');
	my_form.elements['cash_' + counter].value				= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Cash_In_Hand, 0, 'NT_FLOAT');
	for (counter = (property.CurrentYear + 1); counter < (property.CurrentYear + 20); counter++) {
		my_form.elements['own_value_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Own_Value, 'NT_FLOAT');
		my_form.elements['bond_amt_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Bond_Amt, 'NT_FLOAT');
		my_form.elements['gearing_ratio_' + counter].value		= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Gearing_Ratio, 'NT_PERC');
		my_form.elements['bond_pmt_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Bond_Pmt, 0, 'NT_FLOAT');
		my_form.elements['rental_income_' + counter].value		= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Rental_Income, 'NT_FLOAT');
		my_form.elements['vacancy_amt_' + counter].value		= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Vacancy_Amt, 0, 'NT_FLOAT');
		my_form.elements['maint_amt_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Maint_Amt, 0, 'NT_FLOAT');
		my_form.elements['comm_amt_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Comm_Amt, 0, 'NT_FLOAT');
		my_form.elements['levies_' + counter].value				= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Levies, 'NT_FLOAT');
		my_form.elements['net_income_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Net_Income, 0, 'NT_FLOAT');
		my_form.elements['ss_' + counter].value					= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Surplus_Shortfall, 0, 'NT_FLOAT');
		my_form.elements['accumulated_' + counter].value		= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Accumulated, 0, 'NT_FLOAT');
		my_form.elements['equity_' + counter].value				= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Equity, 0, 'NT_FLOAT');
		my_form.elements['nroi_' + counter].value				= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].NROI, 0, 'NT_FLOAT');
		my_form.elements['cashflow_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Cashflow, 0, 'NT_FLOAT');
		my_form.elements['acc_ror_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Acc_ROR, 0, 'NT_PERC');
		my_form.elements['provision_' + counter].value			= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Provision, 0, 'NT_FLOAT');
		my_form.elements['cash_' + counter].value				= SimpleDisplay (prop_config, target_currency, exchange_rates, projection[counter].Cash_In_Hand, 0, 'NT_FLOAT');
	}

	for (counter = property.CurrentYear; counter <= (property.CurrentYear + 19); counter++) {
		if (projection[counter].Gearing_Ratio > prop_config.Gearing) my_form.elements['gearing_ratio_' + counter].style.color = 'red';
		if (projection[counter].Bond_Pmt <= 0) my_form.elements['bond_pmt_' + counter].style.color = 'red';
		if (projection[counter].Vacancy_Amt <= 0) my_form.elements['vacancy_amt_' + counter].style.color = 'red';
		if (projection[counter].Maint_Amt <= 0) my_form.elements['maint_amt_' + counter].style.color = 'red';
		if (projection[counter].Comm_Amt <= 0) my_form.elements['comm_amt_' + counter].style.color = 'red';
		if (projection[counter].Net_Income <= 0) my_form.elements['net_income_' + counter].style.color = 'red';
		if (projection[counter].Surplus_Shortfall <= 0) my_form.elements['ss_' + counter].style.color = 'red';
		if (projection[counter].Accumulated <= 0) my_form.elements['accumulated_' + counter].style.color = 'red';
		if (projection[counter].Equity <= 0) my_form.elements['equity_' + counter].style.color = 'red';
		if (projection[counter].NROI <= 0) my_form.elements['nroi_' + counter].style.color = 'red';
		if (projection[counter].Cashflow <= 0) my_form.elements['cashflow_' + counter].style.color = 'red';
		if (projection[counter].Acc_ROR <= 0) my_form.elements['acc_ror_' + counter].style.color = 'red';
		if (projection[counter].Provision <= 0) my_form.elements['provision_' + counter].style.color = 'red';
		if (projection[counter].Cash_In_Hand <= 0) my_form.elements['cash_' + counter].style.color = 'red';
	}
}

function calcHistoryYear(property, prop_config, history_year, my_form) {
	// The following fields need to be added to the Property History
	//		Deposit
	//		Costs
	//		Purchase Price
	var year				= new Object();
	year.Own_Value			= parseFloat (unformat_number (my_form.elements['own_value_' + history_year].value, prop_config.Currency_Decimals));
	year.Bond_Amt			= parseFloat (unformat_number (my_form.elements['bond_amt_' + history_year].value, prop_config.Currency_Decimals));
	year.Bond_Pmt			= parseFloat (unformat_number (my_form.elements['bond_pmt_' + history_year].value, prop_config.Currency_Decimals));
	year.Rental_Income		= parseFloat (unformat_number (my_form.elements['rental_income_' + history_year].value, prop_config.Currency_Decimals));
	year.Vacancy_Amt		= parseFloat (unformat_number (my_form.elements['vacancy_amt_' + history_year].value, prop_config.Currency_Decimals));
	year.Maint_Amt			= parseFloat (unformat_number (my_form.elements['maint_amt_' + history_year].value, prop_config.Currency_Decimals));
	year.Comm_Amt			= parseFloat (unformat_number (my_form.elements['comm_amt_' + history_year].value, prop_config.Currency_Decimals));
	year.Levies				= parseFloat (unformat_number (my_form.elements['levies_' + history_year].value, prop_config.Currency_Decimals));
	year.Eq_With			= parseFloat (unformat_number (my_form.elements['eq_with_' + history_year].value, prop_config.Currency_Decimals));

	if (year.Own_Value > 0.00) {
		year.Gearing_Ratio		= (year.Bond_Amt / year.Own_Value) * 100;
	} else {
		year.Gearing_Ratio		= 0;
	}
	year.Net_Income			= year.Rental_Income - (year.Vacancy_Amt + year.Maint_Amt + year.Comm_Amt + year.Levies);
	year.Surplus_Shortfall	= year.Net_Income - year.Bond_Pmt;
	year.Equity				= year.Own_Value - year.Bond_Amt;
	year.NROI				= year.Equity - property.Deposit - property.Costs + year.Surplus_Shortfall;
	year.Cashflow			= (year.Bond_Amt - property.Purchase_Price - property.Costs) + year.Surplus_Shortfall;
	if (year.Cashflow < 0) {
		year.Acc_ROR			= (year.NROI / Math.abs (year.Cashflow)) * 100;
	} else {
		year.Acc_ROR			= 0.00;
	}

	my_form.elements['gearing_ratio_' + history_year].value		= SimpleDisplay (prop_config, prop_config.Currency, Array(), year.Gearing_Ratio, 'NT_PERC');
	my_form.elements['net_income_' + history_year].value		= SimpleDisplay (prop_config, prop_config.Currency, Array(), year.Net_Income, 'NT_FLOAT');
	my_form.elements['ss_' + history_year].value				= SimpleDisplay (prop_config, prop_config.Currency, Array(), year.Surplus_Shortfall, 'NT_FLOAT');
	my_form.elements['accumulated_' + history_year].value		= 'n/a';
	my_form.elements['equity_' + history_year].value			= SimpleDisplay (prop_config, prop_config.Currency, Array(), year.Equity, 'NT_FLOAT');
	my_form.elements['nroi_' + history_year].value				= SimpleDisplay (prop_config, prop_config.Currency, Array(), year.NROI, 'NT_FLOAT');
	my_form.elements['cashflow_' + history_year].value			= SimpleDisplay (prop_config, prop_config.Currency, Array(), year.Cashflow, 'NT_FLOAT');
	my_form.elements['acc_ror_' + history_year].value			= 'n/a';
	my_form.elements['provision_' + history_year].value			= 'n/a';
	my_form.elements['cash_' + history_year].value				= 'n/a';
}
